@@ -1,12 +1,11 @@
 package Perinci::Sub::Complete;
 
-our $DATE = '2015-04-27'; # DATE
-our $VERSION = '0.79'; # VERSION
+our $DATE = '2015-08-11'; # DATE
+our $VERSION = '0.80'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use experimental 'smartmatch';
 use Log::Any::IfLOG '$log';
 
 use Complete;
@@ -964,7 +963,7 @@ Perinci::Sub::Complete - Complete command-line argument using Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.79 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-04-27.
+This document describes version 0.80 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-08-11.
 
 =head1 SYNOPSIS
 
@@ -978,8 +977,9 @@ this module.
 
 =head2 complete_arg_elem(%args) -> array
 
-Given argument name and function metadata, complete array element.
+{en_US Given argument name and function metadata, complete array element}.
 
+{en_US 
 Will attempt to complete using the completion routine specified in the argument
 specification (the C<completion> property, or in the case of C<complete_arg_elem>
 function, the C<element_completion> property), or if that is not specified, from
@@ -1009,6 +1009,7 @@ Completion routine should return a completion answer structure (described in
 C<Complete>) which is either a hash or an array. The simplest form of answer is
 just to return an array of strings. Completion routine can also return undef to
 express declination.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -1016,36 +1017,39 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg>* => I<str>
 
-Argument name.
+{en_US Argument name}.
 
 =item * B<args> => I<hash>
 
-Collected arguments so far, will be passed to completion routines.
+{en_US Collected arguments so far, will be passed to completion routines}.
 
 =item * B<ci> => I<bool>
 
-Whether to be case-insensitive.
+{en_US Whether to be case-insensitive}.
 
 =item * B<extras> => I<hash>
 
-Add extra arguments to completion routine.
+{en_US Add extra arguments to completion routine}.
 
+{en_US 
 The keys from this C<extras> hash will be merged into the final C<%args> passed to
 completion routines. Note that standard keys like C<word>, C<cword>, C<ci>, and so
 on as described in the function description will not be overwritten by this.
+}
 
 =item * B<index> => I<int>
 
-Index of element to complete.
+{en_US Index of element to complete}.
 
 =item * B<meta>* => I<hash>
 
-Rinci function metadata, must be normalized.
+{en_US Rinci function metadata, must be normalized}.
 
 =item * B<riap_client> => I<obj>
 
-Optional, to perform complete_arg_val to the server.
+{en_US Optional, to perform complete_arg_val to the server}.
 
+{en_US 
 When the argument spec in the Rinci metadata contains C<completion> key, this
 means there is custom completion code for that argument. However, if retrieved
 from a remote server, sometimes the C<completion> key no longer contains the code
@@ -1055,22 +1059,27 @@ on the server.
 If supplied this argument and te C<riap_server_url> argument, the function will
 try to request to the server (via Riap request C<complete_arg_val>). Otherwise,
 the function will just give up/decline completing.
+}
 
 =item * B<riap_server_url> => I<str>
 
-Optional, to perform complete_arg_val to the server.
+{en_US Optional, to perform complete_arg_val to the server}.
 
+{en_US 
 See the C<riap_client> argument.
+}
 
 =item * B<riap_uri> => I<str>
 
-Optional, to perform complete_arg_val to the server.
+{en_US Optional, to perform complete_arg_val to the server}.
 
+{en_US 
 See the C<riap_client> argument.
+}
 
 =item * B<word> => I<str> (default: "")
 
-Word to be completed.
+{en_US Word to be completed}.
 
 =back
 
@@ -1079,8 +1088,9 @@ Return value:  (array)
 
 =head2 complete_arg_val(%args) -> array
 
-Given argument name and function metadata, complete value.
+{en_US Given argument name and function metadata, complete value}.
 
+{en_US 
 Will attempt to complete using the completion routine specified in the argument
 specification (the C<completion> property, or in the case of C<complete_arg_elem>
 function, the C<element_completion> property), or if that is not specified, from
@@ -1110,6 +1120,7 @@ Completion routine should return a completion answer structure (described in
 C<Complete>) which is either a hash or an array. The simplest form of answer is
 just to return an array of strings. Completion routine can also return undef to
 express declination.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -1117,32 +1128,35 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg>* => I<str>
 
-Argument name.
+{en_US Argument name}.
 
 =item * B<args> => I<hash>
 
-Collected arguments so far, will be passed to completion routines.
+{en_US Collected arguments so far, will be passed to completion routines}.
 
 =item * B<ci> => I<bool>
 
-Whether to be case-insensitive.
+{en_US Whether to be case-insensitive}.
 
 =item * B<extras> => I<hash>
 
-Add extra arguments to completion routine.
+{en_US Add extra arguments to completion routine}.
 
+{en_US 
 The keys from this C<extras> hash will be merged into the final C<%args> passed to
 completion routines. Note that standard keys like C<word>, C<cword>, C<ci>, and so
 on as described in the function description will not be overwritten by this.
+}
 
 =item * B<meta>* => I<hash>
 
-Rinci function metadata, must be normalized.
+{en_US Rinci function metadata, must be normalized}.
 
 =item * B<riap_client> => I<obj>
 
-Optional, to perform complete_arg_val to the server.
+{en_US Optional, to perform complete_arg_val to the server}.
 
+{en_US 
 When the argument spec in the Rinci metadata contains C<completion> key, this
 means there is custom completion code for that argument. However, if retrieved
 from a remote server, sometimes the C<completion> key no longer contains the code
@@ -1152,22 +1166,27 @@ on the server.
 If supplied this argument and te C<riap_server_url> argument, the function will
 try to request to the server (via Riap request C<complete_arg_val>). Otherwise,
 the function will just give up/decline completing.
+}
 
 =item * B<riap_server_url> => I<str>
 
-Optional, to perform complete_arg_val to the server.
+{en_US Optional, to perform complete_arg_val to the server}.
 
+{en_US 
 See the C<riap_client> argument.
+}
 
 =item * B<riap_uri> => I<str>
 
-Optional, to perform complete_arg_val to the server.
+{en_US Optional, to perform complete_arg_val to the server}.
 
+{en_US 
 See the C<riap_client> argument.
+}
 
 =item * B<word> => I<str> (default: "")
 
-Word to be completed.
+{en_US Word to be completed}.
 
 =back
 
@@ -1176,12 +1195,14 @@ Return value:  (array)
 
 =head2 complete_cli_arg(%args) -> hash
 
-Complete command-line argument using Rinci function metadata.
+{en_US Complete command-line argument using Rinci function metadata}.
 
+{en_US 
 This routine uses C<Perinci::Sub::GetArgs::Argv> to generate C<Getopt::Long>
 specification from arguments list in Rinci function metadata and common options.
 Then, it will use C<Complete::Getopt::Long> to complete option names, option
 values, as well as arguments.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -1189,8 +1210,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<common_opts> => I<hash>
 
-Common options.
+{en_US Common options}.
 
+{en_US 
 A hash where the values are hashes containing these keys: C<getopt> (Getopt::Long
 option specification), C<handler> (Getopt::Long handler). Will be passed to
 C<get_args_from_argv()>. Example:
@@ -1208,10 +1230,13 @@ C<get_args_from_argv()>. Example:
      },
  }
 
+}
+
 =item * B<completion> => I<code>
 
-Supply custom completion routine.
+{en_US Supply custom completion routine}.
 
+{en_US 
 If supplied, instead of the default completion routine, this code will be called
 instead. Will receive all arguments that C<Complete::Getopt::Long> will pass, and
 additionally:
@@ -1223,44 +1248,50 @@ additionally:
 =item * C<args> (hash, the function arguments formed so far)
 
 =item * C<index> (int, if completing argument element value)
+}
 
 =back
 
 =item * B<cword>* => I<int>
 
-On which argument cursor is located (zero-based).
+{en_US On which argument cursor is located (zero-based)}.
 
 =item * B<extras> => I<hash>
 
-Add extra arguments to completion routine.
+{en_US Add extra arguments to completion routine}.
 
+{en_US 
 The keys from this C<extras> hash will be merged into the final C<%args> passed to
 completion routines. Note that standard keys like C<word>, C<cword>, C<ci>, and so
 on as described in the function description will not be overwritten by this.
+}
 
 =item * B<func_arg_starts_at> => I<int> (default: 0)
 
+{en_US 
 This is a (temporary?) workaround for Perinci::CmdLine. In an application with
 subcommands (e.g. C<cmd --verbose subcmd arg0 arg1 ...>), then C<words> will still
 contain the subcommand name. Positional function arguments then start at 1 not
 0. This option allows offsetting function arguments.
+}
 
 =item * B<meta>* => I<hash>
 
-Rinci function metadata.
+{en_US Rinci function metadata}.
 
 =item * B<per_arg_json> => I<bool>
 
-Will be passed to Perinci::Sub::GetArgs::Argv.
+{en_US Will be passed to Perinci::Sub::GetArgs::Argv}.
 
 =item * B<per_arg_yaml> => I<bool>
 
-Will be passed to Perinci::Sub::GetArgs::Argv.
+{en_US Will be passed to Perinci::Sub::GetArgs::Argv}.
 
 =item * B<riap_client> => I<obj>
 
-Optional, to perform complete_arg_val to the server.
+{en_US Optional, to perform complete_arg_val to the server}.
 
+{en_US 
 When the argument spec in the Rinci metadata contains C<completion> key, this
 means there is custom completion code for that argument. However, if retrieved
 from a remote server, sometimes the C<completion> key no longer contains the code
@@ -1270,40 +1301,49 @@ on the server.
 If supplied this argument and te C<riap_server_url> argument, the function will
 try to request to the server (via Riap request C<complete_arg_val>). Otherwise,
 the function will just give up/decline completing.
+}
 
 =item * B<riap_server_url> => I<str>
 
-Optional, to perform complete_arg_val to the server.
+{en_US Optional, to perform complete_arg_val to the server}.
 
+{en_US 
 See the C<riap_client> argument.
+}
 
 =item * B<riap_uri> => I<str>
 
-Optional, to perform complete_arg_val to the server.
+{en_US Optional, to perform complete_arg_val to the server}.
 
+{en_US 
 See the C<riap_client> argument.
+}
 
 =item * B<words>* => I<array[str]>
 
-Command-line arguments.
+{en_US Command-line arguments}.
 
 =back
 
 Return value:  (hash)
 
 
+{en_US 
 You can use C<format_completion> function in C<Complete::Bash> module to format
 the result of this function for bash.
+}
 
 
 =head2 complete_from_schema(%args) -> [status, msg, result, meta]
 
-Complete a value from schema.
+{en_US Complete a value from schema}.
 
+{en_US 
 Employ some heuristics to complete a value from Sah schema. For example, if
 schema is C<< [str =E<gt> in =E<gt> [qw/new open resolved rejected/]] >>, then we can
 complete from the C<in> clause. Or for something like C<< [int =E<gt> between =E<gt> [1,
 20]] >> we can complete using values from 1 to 20.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -1313,7 +1353,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
-Must be normalized.
+{en_US Must be normalized}.
 
 =item * B<word>* => I<str> (default: "")
 
